Importing from BibTeX or Zotero
===============================

Many users will want to import a library from a bibtex file
that another program such as ``zotero``, ``mendeley`` or
``jabref`` will have exported. These programs usually have a
field called ``FILE`` or ``file`` that points to a path
where the document file can be found.

To import such a library you can use a provided script originally
intended for ``zotero`` which is, however, general enough to work
for other programs too.

To install this script you can install the project
`papis-zotero <https://github.com/papis/papis-zotero>`__ and follow the
instructions therein to import a bibliography file into Papis.

You can also take a look at the
`zotero2papis <https://github.com/nicolasshu/zotero2papis>`__ project
in order to see a different workflow
and different implementation of a converter script.
`This <https://nicolasshu.com/zotero_and_papis.html>`__ blogpost
explains the workflow using Papis with zotero and SyncThing.
